"""
    This is a wrapper from invoke
"""
import logging
from invoke import Collection
from invoke import Program
from .bump_version import bump_version

logging.basicConfig(level=logging.INFO)

ns = Collection()
ns.add_task(bump_version)

program = Program(version="0.0.45", namespace=ns)



from invoke import task

@task
def bump_version(ctx, part, confirm=False):
    if confirm:
        ctx.run('bumpversion {part}'.format(part=part))
    else:
        ctx.run('bumpversion --dry-run --allow-dirty --verbose {part}'.format(part=part))
        print('Add "--confirm" to actually perform the bump version.')

